<?php
/**
 * ReduxFramework Barebones Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 *
 * @package AttorneyPress
 */

if ( ! class_exists( 'Redux' ) ) {
	return;
}
// This is your option name where all the Redux data is stored.
$opt_name = 'attorneypress_theme_option';
/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */
$theme = wp_get_theme(); // For use with some settings. Not necessary.
$args  = array(
	// TYPICAL -> Change these values as you need/desire.
	'opt_name'             => $opt_name,
	'disable_tracking'     => true,
	'display_name'         => $theme->get( 'Name' ),
	'display_version'      => $theme->get( 'Version' ),
	'menu_type'            => 'menu',
	'allow_sub_menu'       => true,
	'menu_title'           => esc_html__( 'Theme Options', 'attorneypress' ),
	'page_title'           => esc_html__( 'Theme Options', 'attorneypress' ),
	'google_api_key'       => '',
	'google_update_weekly' => false,
	'async_typography'     => true,
	'admin_bar'            => true,
	'admin_bar_icon'       => 'dashicons-hammer',
	'admin_bar_priority'   => 50,
	'global_variable'      => '',
	'dev_mode'             => false,
	'update_notice'        => false,
	'customizer'           => false,
	'page_priority'        => 61,
	'page_parent'          => 'themes.php',
	'page_permissions'     => 'manage_options',
	'menu_icon'            => 'dashicons-hammer',
	'last_tab'             => '',
	'page_icon'            => 'icon-themes',
	'page_slug'            => '_options',
	'save_defaults'        => true,
	'default_show'         => false,
	'default_mark'         => '',
	'footer_credit'        => $theme->get( 'Name' ),
	'show_import_export'   => true,
	'show_options_object'  => false,
	'transient_time'       => 60 * MINUTE_IN_SECONDS,
	'output'               => true,
	'output_tag'           => true,
	'database'             => '',
	'use_cdn'              => true,
	'hints'                => array(
		'icon_position' => 'right',
		'icon_size'     => 'normal',
		'tip_style'     => array(
			'color' => 'light',
		),
		'tip_position' => array(
			'my' => 'top left',
			'at' => 'bottom right',
		),
		'tip_effect' => array(
			'show' => array(
				'duration' => '500',
				'event'    => 'mouseover',
			),
			'hide' => array(
				'duration' => '500',
				'event'    => 'mouseleave unfocus',
			),
		),
	),
);

Redux::setArgs( $opt_name, $args );

/*
 * ---> END ARGUMENTS
 */

/*
 *
 * ---> START SECTIONS
 *
 */

/*
  As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for
 */

// -> START Basic Fields.
Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Getting Started', 'attorneypress' ),
	'icon'   => 'fa fa-list',
	'fields' => array(
		array(
			'id'   => 'theme_info',
			'type' => 'info',
			'desc' => wp_kses_post( '<h3>Welcome to the Options panel of the ' . wp_get_theme()->get( 'Name' ) . '!</h3><h4>What does this mean to you?</h4><p>From here on you will be able to regulate the main options of all the elements of the theme. </p><p>Theme documentation you will find here: <a href="' . esc_url( 'http://themes.radiantthemes.com/attorneypress/docs/' ) . '" target="_blank">http://themes.radiantthemes.com/attorneypress/docs/</a></p>' ),
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'   => esc_html__( 'General Settings', 'attorneypress' ),
	'submenu' => true,
	'icon'    => 'fa fa-sun-o',
	'fields' => array(
                array(
                        'id'       => 'color_scheme',
                        'type'     => 'select',
                        'title'    => __('Select Theme Color', 'attorneypress'), 
                        'subtitle' => __('Form here you can select preset theme color. ', 'attorneypress'),
                        'options'  => array(
								'dark'      => 'Dark',
								'dark-two'  => 'Dark Two',
                                'light'     => 'Light'
                        ),
                        'default'  => 'dark',
                ),
		array(
			'id'       => 'theme-color',
			'type'     => 'color',
			'title'    => esc_html__( 'Anchor Color', 'attorneypress' ),
			'subtitle' => esc_html__( 'This section represents anchor color.', 'attorneypress' ),
			'default'  => '#a68f65',
			'output'   => array( 'a' ),
		),
		array(
			'id'       => 'anchor-hover-color',
			'type'     => 'color',
			'title'    => esc_html__( 'Anchor Hover Color', 'attorneypress' ),
			'subtitle' => esc_html__( 'This section represents anchor hover color.', 'attorneypress' ),
			'default'  => '#a68f65',
			'output'   => array( 'a:hover, a:visited' ),
		),
		array(
			'id'       => 'separator-color',
			'type'     => 'color',
			'title'    => esc_html__( 'Heading Separator Color', 'attorneypress' ),
			'subtitle' => esc_html__( 'This section represents heading separator color in the Inner pages like Single Attorneys Profile, Single Practice Areas, Attorney Profession.', 'attorneypress' ),
			'default'  => '#9c865f',
			'output'   => array(
				'border-color' => '.vc_separator > .vc_sep_holder > .custom-separator',
			),
		),
		array(
			'id'                    => 'body-color',
			'type'                  => 'background',
			'title'                 => esc_html__( 'Body Background Color', 'attorneypress' ),
			'subtitle'              => esc_html__( 'Pick a background color for the theme.', 'attorneypress' ),
			'background-color'      => true,
			'background-repeat'     => false,
			'background-attachment' => false,
			'background-position'   => false,
			'background-image'      => false,
			'background-clip'       => false,
			'background-origin'     => false,
			'background-size'       => false,
			'preview_media'         => false,
			'preview'               => false,
			'transparent'           => true,
			'default'               => array(
				'background-color' => '#fff',
			),
			'output'                => array( 'body' ),
		),
		array(
			'id'       => 'scrollto_top_button',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display ScrollTo Top Button', 'attorneypress' ),
			'subtitle' => esc_html__( 'Choose do you want to keep scrollto top button or not?', 'attorneypress' ),
			'default'  => true,
		),
		array(
			'id'       => 'scrollto_top_position',
			'type'     => 'radio',
			'title'    => esc_html__( 'ScrollTo Top Button Position', 'attorneypress' ),
			'subtitle' => esc_html__( 'Show the ScrollTo Top Button Position.', 'attorneypress' ),
			'required' => array(
				array(
					'scrollto_top_button',
					'equals',
					true,
				),
			),
			'options' => array(
				'1' => 'Right',
				'2' => 'Left',
			),
			'default' => '2',
		),
		array(
			'id'      => 'sidepanel_form',
			'type'    => 'switch',
			'title'   => esc_html__( 'Display Floating Contact Form', 'attorneypress' ),
		),
		array(
			'id'       => 'sidepanel_position',
			'type'     => 'radio',
			'title'    => esc_html__( 'Floating Contact Form Position', 'attorneypress' ),
			'required' => array(
				array(
					'sidepanel_form',
					'equals',
					true,
				),
			),
			'options' => array(
				'1' => 'Right',
				'2' => 'Left',
			),
			'default' => '1',
		),
		array(
			'id'       => 'sidepanel_title',
			'type'     => 'text',
			'title'    => esc_html__( 'Floating Contact Form Title', 'attorneypress' ),
			'default'  => 'Schedule A Callback',
			'required' => array(
				array(
					'sidepanel_form',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'sidepanel_description',
			'type'     => 'editor',
			'title'    => esc_html__( 'Floating Contact Form Brief Description', 'attorneypress' ),
			'default'  => wp_kses_post( '<h3>Schedule A Callback</h3><p>Lorem Ipsum is simply dummy text of the printing and typesetting industry.</p>' ),
			'args'     => array(
				'teeny' => false,
			),
			'required' => array(
				array(
					'sidepanel_form',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'sidepanel_form_shortcode',
			'type'     => 'text',
			'title'    => esc_html__( 'Floating Contact Form Shortcode', 'attorneypress' ),
			'subtitle' => esc_html__( 'Copy the floating contact form 7 shortcode and paste here.', 'attorneypress' ),
			'default'  => '[contact-form-7 id="233" title="Floating Schedule Callback Form"]',
			'required' => array(
				array(
					'sidepanel_form',
					'equals',
					true,
				),
			),
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'   => esc_html__( 'Mobile Settings', 'attorneypress' ),
	'submenu' => true,
	'icon'    => 'fa fa-mobile',
	'fields'  => array(
		array(
			'id'       => 'header_top_show',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display Header Top Area On Mobile', 'attorneypress' ),
			'subtitle' => esc_html__( 'Choose do you want to keep header top area on mobile or not?', 'attorneypress' ),
			'default'  => true,
		),
		array(
			'id'       => 'header_innerbanner_show',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display Header Inner Banner Area On Mobile', 'attorneypress' ),
			'subtitle' => esc_html__( 'Choose do you want to keep header banner area on mobile or not?', 'attorneypress' ),
			'default'  => true,
		),
		array(
			'id'       => 'footer_contactbar_show',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display Footer Contact Bar On Mobile', 'attorneypress' ),
			'subtitle' => esc_html__( 'Choose do you want to keep footer contact bar on mobile or not?', 'attorneypress' ),
			'default'  => true,
		),
		array(
			'id'       => 'footer_main_show',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display Footer Main Area On Mobile', 'attorneypress' ),
			'subtitle' => esc_html__( 'Choose do you want to keep footer main area on mobile or not?', 'attorneypress' ),
			'default'  => true,
		),
		array(
			'id'       => 'mobile_navigation_position',
			'type'     => 'radio',
			'title'    => esc_html__( 'Mobile Navigation Position', 'attorneypress' ),
			'subtitle' => esc_html__( 'Show the Mobile Navigation Position.', 'attorneypress' ),
			'options'  => array(
				'1' => 'Right',
				'2' => 'Left',
			),
			'default'  => '1',
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Header', 'attorneypress' ),
	'icon'  => 'fa fa-h-square',
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Header Style', 'attorneypress' ),
	'icon'       => 'fa fa-pencil',
	'subsection' => true,
	'fields'     => array(
		array(
			'id'       => 'header-style',
			'type'     => 'image_select',
			'title'    => esc_html__( 'Header Style', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select header style.', 'attorneypress' ),
			'options'  => array(
				'header-style-one' => array(
					'alt'   => esc_html__( 'Style One', 'attorneypress' ),
					'title' => esc_html__( 'Style One', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/header-style-one.png' ),
				),
				'header-style-two' => array(
					'alt'   => esc_html__( 'Style Two', 'attorneypress' ),
					'title' => esc_html__( 'Style Two', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/header-style-two.png' ),
				),
				'header-style-three' => array(
					'alt'   => esc_html__( 'Style Three', 'attorneypress' ),
					'title' => esc_html__( 'Style Three', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/header-style-three.png' ),
				),
			),
			'default' => 'header-style-one',
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Header Options', 'attorneypress' ),
	'subsection' => true,
	'icon'       => 'fa fa-bars',
	'fields'     => array(
		array(
			'id'       => 'sticky_header',
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable Floating Contact Header', 'attorneypress' ),
			'subtitle' => esc_html__( 'Do you want to enable Floating Contact header?', 'attorneypress' ),
			'default'  => true,
		),
		array(
			'id'       => 'enable_address',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display Address', 'attorneypress' ),
			'subtitle' => esc_html__( 'Do you want to display address?', 'attorneypress' ),
			'default'  => true,
		),
		array(
			'id'       => 'top_header_address',
			'type'     => 'text',
			'title'    => esc_html__( 'Top Header Address', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter top header address', 'attorneypress' ),
			'default'  => esc_html__( 'Ashland Ave Chicago IL 60608', 'attorneypress' ),
			'required' => array(
				array(
					'enable_address',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'enable_phone',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display Phone Number', 'attorneypress' ),
			'subtitle' => esc_html__( 'Do you want to display phone number?', 'attorneypress' ),
			'default'  => true,
		),
		array(
			'id'       => 'top_header_phone',
			'type'     => 'text',
			'title'    => esc_html__( 'Top Header Phone', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter top header phone number', 'attorneypress' ),
			'default'  => esc_html__( '(888) 346-8922', 'attorneypress' ),
			'required' => array(
				array(
					'enable_phone',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'enable_email',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display Email', 'attorneypress' ),
			'subtitle' => esc_html__( 'Do you want to display email?', 'attorneypress' ),
			'default'  => true,
		),
		array(
			'id'       => 'top_header_email',
			'type'     => 'text',
			'title'    => esc_html__( 'Top Header Email', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter top header email', 'attorneypress' ),
			'validate' => 'email',
			'default'  => sanitize_email( 'contact@attorneypress.com' ),
			'required' => array(
				array(
					'enable_email',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'enable_facebook',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display Facebook Link', 'attorneypress' ),
			'subtitle' => esc_html__( 'Do you want to display Facebook link?', 'attorneypress' ),
			'default'  => true,
		),
		array(
			'id'       => 'top_header_facebook',
			'type'     => 'text',
			'title'    => esc_html__( 'Top Header Facebook Link', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter header Facebook link', 'attorneypress' ),
			'default'  => esc_url( 'https://facebook.com/' ),
			'required' => array(
				array(
					'enable_facebook',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'enable_twitter',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display Twitter Link', 'attorneypress' ),
			'subtitle' => esc_html__( 'Do you want to display Twitter link?', 'attorneypress' ),
			'default'  => true,
		),
		array(
			'id'       => 'top_header_twitter',
			'type'     => 'text',
			'title'    => esc_html__( 'Top Header Twitter Link', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter header Twitter link', 'attorneypress' ),
			'default'  => esc_url( 'https://twitter.com/' ),
			'required' => array(
				array(
					'enable_twitter',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'enable_linkedin',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display Linkedin', 'attorneypress' ),
			'subtitle' => esc_html__( 'Do you want to display Linkedin link?', 'attorneypress' ),
			'default'  => true,
		),
		array(
			'id'       => 'top_header_linkedin',
			'type'     => 'text',
			'title'    => esc_html__( 'Top Header Linkedin Link', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter header Linkedin link', 'attorneypress' ),
			'default'  => esc_url( 'https://linkedin.com/' ),
			'required' => array(
				array(
					'enable_linkedin',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'enable_googleplus',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display Google+', 'attorneypress' ),
			'subtitle' => esc_html__( 'Do you want to display Google+ link?', 'attorneypress' ),
			'default'  => true,
		),
		array(
			'id'       => 'top_header_googleplus',
			'type'     => 'text',
			'title'    => esc_html__( 'Top Header Google+ Link', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter header Google+ link', 'attorneypress' ),
			'default'  => esc_url( 'https://plus.google.com/' ),
			'required' => array(
				array(
					'enable_googleplus',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'enable_youtube',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display YouTube', 'attorneypress' ),
			'subtitle' => esc_html__( 'Do you want to display YouTube link?', 'attorneypress' ),
			'default'  => true,
		),
		array(
			'id'       => 'top_header_youtube',
			'type'     => 'text',
			'title'    => esc_html__( 'Top Header Youtube Link', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter header Youtube link', 'attorneypress' ),
			'default'  => esc_url( 'https://youtube.com/' ),
			'required' => array(
				array(
					'enable_youtube',
					'equals',
					true,
				),
			),
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Footer', 'attorneypress' ),
	'icon'  => 'fa fa-align-center',
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Footer Style', 'attorneypress' ),
	'icon'       => 'fa fa-pencil',
	'subsection' => true,
	'fields'     => array(
		array(
			'id'       => 'footer-style',
			'type'     => 'image_select',
			'title'    => esc_html__( 'Footer Style', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select footer style.', 'attorneypress' ),
			'options'  => array(
				'footer-style-one' => array(
					'alt'   => esc_html__( 'Style One', 'attorneypress' ),
					'title' => esc_html__( 'Style One', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/footer-style-one.png' ),
				),
				'footer-style-two' => array(
					'alt'   => esc_html__( 'Style Two', 'attorneypress' ),
					'title' => esc_html__( 'Style Two', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/footer-style-two.png' ),
				),
			),
		),
		array(
			'id'       => 'contactbar_display',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display Contact Bar', 'attorneypress' ),
			'subtitle' => esc_html__( 'Choose do you want to keep Contact Bar or not?', 'attorneypress' ),
			'default'  => true,
			'required' => array(
				array(
					'footer-style',
					'equals',
					'footer-style-one',
				),
			),
		),
		array(
			'id'       => 'phone_title',
			'type'     => 'text',
			'url'      => true,
			'title'    => esc_html__( 'Phone Title', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter phone title', 'attorneypress' ),
			'default'  => esc_html__( 'CALL US NOW !', 'attorneypress' ),
			'required' => array(
				array(
					'contactbar_display',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'phone_no',
			'type'     => 'text',
			'url'      => true,
			'title'    => esc_html__( 'Phone No', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter phone number', 'attorneypress' ),
			'default'  => esc_html__( '(888) 346-8922', 'attorneypress' ),
			'required' => array(
				array(
					'contactbar_display',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'phone_availability_time',
			'type'     => 'text',
			'url'      => true,
			'title'    => esc_html__( 'Phone Availability Time', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter phone availability time', 'attorneypress' ),
			'default'  => esc_html__( 'Free Consultation', 'attorneypress' ),
			'required' => array(
				array(
					'contactbar_display',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'mail_title',
			'type'     => 'text',
			'url'      => true,
			'title'    => esc_html__( 'Mail Title', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter mail title', 'attorneypress' ),
			'default'  => esc_html__( 'SEND US MESSAGE !', 'attorneypress' ),
			'required' => array(
				array(
					'contactbar_display',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'mail_id',
			'type'     => 'text',
			'url'      => true,
			'title'    => esc_html__( 'Mail ID', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter mail id', 'attorneypress' ),
			'default'  => sanitize_email( 'info@attorneypress.com' ),
			'required' => array(
				array(
					'contactbar_display',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'mail_availability_time',
			'type'     => 'text',
			'url'      => true,
			'title'    => esc_html__( 'Mail Availability Time', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter mail availability time', 'attorneypress' ),
			'default'  => esc_html__( 'Free Consultation', 'attorneypress' ),
			'required' => array(
				array(
					'contactbar_display',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'area_title',
			'type'     => 'text',
			'url'      => true,
			'title'    => esc_html__( 'Area Title', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter area title', 'attorneypress' ),
			'default'  => esc_html__( 'VISIT OUR OFFICE !', 'attorneypress' ),
			'required' => array(
				array(
					'contactbar_display',
					'equals',
					true,
				),
			),
		),
		array(
			'id'       => 'area_address',
			'type'     => 'text',
			'url'      => true,
			'title'    => esc_html__( 'Area Address', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter area address', 'attorneypress' ),
			'default'  => esc_html__( 'PO Box 16122 Collins Street West Victoria 8007 Australia', 'attorneypress' ),
			'required' => array(
				array(
					'contactbar_display',
					'equals',
					true,
				),
			),
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Footer Widget', 'attorneypress' ),
	'subsection' => true,
	'icon'       => 'fa fa-phone-square',
	'fields'     => array(
		array(
			'id'       => 'footer_widget_display',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display Footer Widget', 'attorneypress' ),
			'subtitle' => esc_html__( 'Choose do you want to keep Footer Widget or not?', 'attorneypress' ),
			'default'  => true,
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Footer Copyright Bar', 'attorneypress' ),
	'subsection' => true,
	'icon'       => 'fa fa-pencil',
	'fields'     => array(
		array(
			'id'       => 'footer_copyright_bar',
			'type'     => 'text',
			'title'    => esc_html__( 'Copyright Text', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter Copyright Text', 'attorneypress' ),
			'default'  => esc_html__( 'AttorneyPress &copy; All Rights Reserved', 'attorneypress' ),
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'  => esc_html__( 'Logo & Favicon', 'attorneypress' ),
	'icon'   => 'fa fa-asterisk',
	'fields' => array(
		array(
			'id'       => 'site_logo',
			'type'     => 'media',
			'url'      => false,
			'title'    => esc_html__( 'Site Logo', 'attorneypress' ),
			'subtitle' => esc_html__( 'Upload site logo (319x78)', 'attorneypress' ),
			'output'   => 'true',
			'default'  => array(
				'url' => get_parent_theme_file_uri( '/images/attorneypress-logo.png' ),
			),
		),
		array(
			'id'       => 'favicon',
			'type'     => 'media',
			'url'      => false,
			'title'    => esc_html__( 'Favicon', 'attorneypress' ),
			'subtitle' => esc_html__( 'Upload favicon (Changes from customization preference first)', 'attorneypress' ),
			'output'   => 'true',
			'default'  => array(
				'url' => get_parent_theme_file_uri( '/images/favicon.ico' ),
			),
		),
		array(
			'id'       => 'apple-icon',
			'type'     => 'media',
			'url'      => false,
			'title'    => esc_html__( 'Apple iPhone Icon', 'attorneypress' ),
			'subtitle' => esc_html__( 'Upload Apple iPhone icon (192x192)', 'attorneypress' ),
			'output'   => 'true',
			'default'  => array(
				'url' => get_parent_theme_file_uri( '/images/icon-192x192.png' ),
			),
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'   => esc_html__( 'Typography', 'attorneypress' ),
	'desc'    => '',
	'id'      => 'basic-settings',
	'icon'    => 'fa fa-text-height',
	'submenu' => true,
	'fields'  => array(
		array(
			'id'             => 'general_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'General', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font of your website.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'letter-spacing' => true,
			'font-style'     => true,
			'all_styles'     => true,
			'output'         => array( 'body' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Montserrat',
				'font-weight' => '300',
				'font-size'   => '15px',
				'color'       => '#393939',
				'line-height' => '26px',
			),
		),
		array(
			'id'             => 'h1_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'H1', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font for all H1 tags of your website.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'font-weight'    => true,
			'font-style'     => true,
			'line-height'    => true,
			'letter-spacing' => true,
			'font-family'    => true,
			'color'          => true,
			'all_styles'     => false,
			'output'         => array( 'h1' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Libre Baskerville',
				'font-weight' => '400',
				'font-size'   => '30px',
				'color'       => '#393939',
				'line-height' => '40px',
			),
		),
		array(
			'id'             => 'h2_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'H2', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font for all H2 tags of your website.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'font-weight'    => true,
			'font-style'     => true,
			'line-height'    => true,
			'letter-spacing' => true,
			'font-family'    => true,
			'color'          => true,
			'all_styles'     => false,
			'output'         => array( 'h2' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Libre Baskerville',
				'font-weight' => '400',
				'font-size'   => '26px',
				'color'       => '#393939',
				'line-height' => '35px',
			),
		),
		array(
			'id'             => 'h3_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'H3', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font for all H3 tags of your website.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'font-weight'    => true,
			'font-style'     => true,
			'line-height'    => true,
			'letter-spacing' => true,
			'font-family'    => true,
			'color'          => true,
			'all_styles'     => false,
			'output'         => array( 'h3' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Libre Baskerville',
				'font-weight' => '400',
				'font-size'   => '23px',
				'color'       => '#393939',
				'line-height' => '35px',
			),
		),
		array(
			'id'             => 'h4_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'H4', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font for all H4 tags of your website.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'font-weight'    => true,
			'font-style'     => true,
			'line-height'    => true,
			'letter-spacing' => true,
			'font-family'    => true,
			'color'          => true,
			'all_styles'     => false,
			'output'         => array( 'h4' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Libre Baskerville',
				'font-weight' => '400',
				'font-size'   => '22px',
				'color'       => '#393939',
				'line-height' => '35px',
			),
		),
		array(
			'id'             => 'h5_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'H5', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font for all H5 tags of your website.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'font-weight'    => true,
			'font-style'     => true,
			'line-height'    => true,
			'letter-spacing' => true,
			'font-family'    => true,
			'color'          => true,
			'all_styles'     => false,
			'output'         => array( 'h5' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Bitter',
				'font-weight' => '400',
				'font-size'   => '20px',
				'color'       => '#393939',
				'line-height' => '30px',
			),
		),
		array(
			'id'             => 'h6_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'H6', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font for all H6 tags of your website.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'font-weight'    => true,
			'font-style'     => true,
			'line-height'    => true,
			'letter-spacing' => true,
			'font-family'    => true,
			'color'          => true,
			'all_styles'     => false,
			'output'         => array( 'h6' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Bitter',
				'font-weight' => '400',
				'font-size'   => '14px',
				'color'       => '#393939',
				'line-height' => '22px',
			),
		),
		array(
			'id'             => 'header_menu_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'Header Menu', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font for header menu.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'font-weight'    => true,
			'font-style'     => true,
			'line-height'    => true,
			'letter-spacing' => true,
			'font-family'    => true,
			'color'          => true,
			'all_styles'     => false,
			'output'         => array( '.nav, .sidr' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Libre Baskerville',
				'font-weight' => '400',
				'font-size'   => '16px',
				'color'       => '#ffffff',
				'line-height' => '25px',
			),
		),
		array(
			'id'             => 'footer_menu_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'Footer Menu', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font for footer menu.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'font-weight'    => true,
			'font-style'     => true,
			'line-height'    => true,
			'letter-spacing' => true,
			'font-family'    => true,
			'color'          => true,
			'all_styles'     => false,
			'output'         => array( '.footer_copyright ul.menu li' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Libre Baskerville',
				'font-weight' => '400',
				'font-size'   => '14px',
				'color'       => '#ffffff',
				'line-height' => '22px',
			),
		),
		array(
			'id'             => 'innerbanner_title_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'Inner Banner Title', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font for inner banner title.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'font-weight'    => true,
			'font-style'     => true,
			'line-height'    => true,
			'letter-spacing' => true,
			'font-family'    => true,
			'color'          => true,
			'all_styles'     => false,
			'output'         => array( '.header_bannerinner .title' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Libre Baskerville',
				'font-weight' => '400',
				'font-size'   => '56px',
				'color'       => '#ffffff',
				'line-height' => '65px',
			),
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Home Page Elements', 'attorneypress' ),
	'icon'  => 'fa fa-file-text',
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Attorney Areas', 'attorneypress' ),
	'desc'       => '',
	'subsection' => true,
	'submenu'    => true,
	'icon'       => 'fa fa-graduation-cap',
	'fields'     => array(
		array(
			'id'       => 'opt-select-attorney-areas',
			'type'     => 'select',
			'multi'    => true,
			'title'    => esc_html__( 'Attorney Areas on Home page', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select attorneys you want to see on home page', 'attorneypress' ),
			'data'     => 'posts',
			'args'     => array(
				'post_type'      => 'attorneys',
				'posts_per_page' => -1,
				'orderby'        => 'title',
				'order'          => 'ASC',
			),
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Practice Areas', 'attorneypress' ),
	'desc'       => '',
	'subsection' => true,
	'submenu'    => true,
	'icon'       => 'fa fa-hourglass-end',
	'fields'     => array(
		array(
			'id'       => 'practice-areas-layout-home-page',
			'type'     => 'image_select',
			'title'    => esc_html__( 'Practice Areas Layout on Home page', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select practice areas layout for home page', 'attorneypress' ),
			'options'  => array(
				'practice-areas-style-1' => array(
					'alt'   => esc_html__( 'Practice Areas Image View', 'attorneypress' ),
					'title' => esc_html__( 'Practice Areas Image View', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/practice-areas-image-view.png' ),
				),
				'practice-areas-style-2' => array(
					'alt'   => esc_html__( 'Icon View 4 columns', 'attorneypress' ),
					'title' => esc_html__( 'Icon View 4 columns', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/practice-areas-icon-view.png' ),
				),
				'practice-areas-style-3' => array(
					'alt'   => esc_html__( 'Icon View 3 columns', 'attorneypress' ),
					'title' => esc_html__( 'Icon View 3 columns', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/practice-areas-icon-view-3col.png' ),
				),
			),
			'default'  => 'practice-areas-style-1',
		),
		array(
			'id'       => 'opt-select-practice-areas',
			'type'     => 'select',
			'multi'    => true,
			'title'    => esc_html__( 'Practice Areas on Home page', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select practice areas you want to see on home page', 'attorneypress' ),
			'data'     => 'posts',
			'args'     => array(
				'post_type'      => 'practice-areas',
				'posts_per_page' => -1,
				'orderby'        => 'title',
				'order'          => 'ASC',
			),
		),
		array(
			'id'                => 'practice-areas-excerpt-length',
			'type'              => 'text',
			'validate_callback' => 'attorneypress_excerpt_length_limit',
			'title'             => esc_html__( 'Excerpt Length', 'attorneypress' ),
			'subtitle'          => esc_html__( 'Put character limit on practice area boxes of home page', 'attorneypress' ),
			'default'           => '72',
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Testimonial Areas', 'attorneypress' ),
	'desc'       => '',
	'subsection' => true,
	'submenu'    => true,
	'icon'       => 'fa fa-list-ul',
	'fields'     => array(
		array(
			'id'       => 'testimonial-layout-home-page',
			'type'     => 'image_select',
			'title'    => esc_html__( 'Testimonial Layout on Home page', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select testimonial layout for home page', 'attorneypress' ),
			'options'  => array(
				'testimonial-style-1' => array(
					'alt'   => esc_html__( 'Testimonial List View', 'attorneypress' ),
					'title' => esc_html__( 'Testimonial List View', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/testimonial-list-view.png' ),
				),
				'testimonial-style-2' => array(
					'alt'   => esc_html__( 'Testimonial Slider View', 'attorneypress' ),
					'title' => esc_html__( 'Testimonial Slider View', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/testimonial-slider-view.png' ),
				),
			),
			'default'  => 'testimonial-style-1',
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Inner Page Elements', 'attorneypress' ),
	'icon'  => 'fa fa-clipboard',
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Practice Areas Listing Layout', 'attorneypress' ),
	'desc'       => '',
	'subsection' => true,
	'submenu'    => true,
	'icon'       => 'fa fa-list-ul',
	'fields'     => array(
		array(
			'id'       => 'practice-areas-listing-layout',
			'type'     => 'image_select',
			'title'    => esc_html__( 'Practice Areas Listing Layout', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select practice area listing layout for Practice Area page', 'attorneypress' ),
			'options'  => array(
				'listview' => array(
					'alt'   => esc_html__( 'List View', 'attorneypress' ),
					'title' => esc_html__( 'List View', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Practice-Areas-Listing-Style-1.png' ),
				),
				'gridview2column' => array(
					'alt'   => esc_html__( 'Grid View 2 columns', 'attorneypress' ),
					'title' => esc_html__( 'Grid View 2 columns', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Practice-Areas-Listing-Style-2.png' ),
				),
				'gridview3column' => array(
					'alt'   => esc_html__( 'Grid View 3 columns', 'attorneypress' ),
					'title' => esc_html__( 'Grid View 3 columns', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Practice-Areas-Listing-Style-3.png' ),
				),
			),
			'default'  => 'listview',
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Attorney Listing Layout', 'attorneypress' ),
	'subsection' => true,
	'submenu'    => true,
	'icon'       => 'fa fa-list-ul',
	'fields'     => array(
		array(
			'id'       => 'attorney-listing-layout',
			'type'     => 'image_select',
			'title'    => esc_html__( 'Attorney Listing Layout', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select attorney listing layout for Attorney page', 'attorneypress' ),
			'options'  => array(
				'attorney-one-layout' => array(
					'alt'   => esc_html__( 'Attorneys 4 Columns', 'attorneypress' ),
					'title' => esc_html__( 'Attorneys 4 Columns', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Attorney-Listing-Style-1.png' ),
				),
				'attorney-two-layout' => array(
					'alt'   => esc_html__( 'Attorneys 3 Columns', 'attorneypress' ),
					'title' => esc_html__( 'Attorneys 3 Columns', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Attorney-Listing-Style-2.png' ),
				),
				'attorney-three-layout' => array(
					'alt'   => esc_html__( 'Attorneys 2 Columns', 'attorneypress' ),
					'title' => esc_html__( 'Attorneys 2 Columns', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Attorney-Listing-Style-3.png' ),
				),
				'attorney-four-layout' => array(
					'alt'   => esc_html__( 'Attorneys List View', 'attorneypress' ),
					'title' => esc_html__( 'Attorneys List View', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Attorney-Listing-Style-4.png' ),
				),
			),
			'default'  => 'attorney-one-layout',
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Testimonial Layout', 'attorneypress' ),
	'desc'       => '',
	'subsection' => true,
	'submenu'    => true,
	'icon'       => 'fa fa-list-ul',
	'fields'     => array(
		array(
			'id'       => 'testimonial-layout',
			'type'     => 'image_select',
			'title'    => esc_html__( 'Testimonial Layout', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select Testimonial layout for Testimonials page', 'attorneypress' ),
			'options'  => array(
				'testimonial-one-layout' => array(
					'alt'   => esc_html__( 'Testimonial List View', 'attorneypress' ),
					'title' => esc_html__( 'Testimonial List View', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Testimonial-Layout-Style-1.png' ),
				),
				'testimonial-three-layout' => array(
					'alt'   => esc_html__( 'Testimonial List View Version2', 'attorneypress' ),
					'title' => esc_html__( 'Testimonial List View Version 2', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/testimonial-list-view-version-2.png' ),
				),
				'testimonial-two-layout' => array(
					'alt'   => esc_html__( 'Testimonial Masonry View', 'attorneypress' ),
					'title' => esc_html__( 'Testimonial Masonry View', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Testimonial-Layout-Style-2.png' ),
				),
			),
			'default' => 'testimonial-one-layout',
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Attorney Single Page Layout', 'attorneypress' ),
	'desc'       => '',
	'subsection' => true,
	'submenu'    => true,
	'icon'       => 'fa fa-graduation-cap',
	'fields'     => array(
		array(
			'id'       => 'attorney-single-page-layout',
			'type'     => 'image_select',
			'title'    => esc_html__( 'Attorney Single Page Layout', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select attorney single page layout', 'attorneypress' ),
			'options'  => array(
				'big-image-layout' => array(
					'alt'   => esc_html__( 'Layout One', 'attorneypress' ),
					'title' => esc_html__( 'Layout One', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Attorney-Details-02.jpg' ),
				),
				'small-image-layout' => array(
					'alt'   => esc_html__( 'Layout Two', 'attorneypress' ),
					'title' => esc_html__( 'Layout Two', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Attorney-Details-01.jpg' ),
				),
				'no-sidebar-layout' => array(
					'alt'   => esc_html__( 'Layout Three', 'attorneypress' ),
					'title' => esc_html__( 'Layout Three', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Attorney-Details-03.jpg' ),
				),
			),
			'default'  => 'big-image-layout',
		),
		array(
			'id'       => 'attorney-single-sidebar-style',
			'type'     => 'select',
			'title'    => esc_html__( 'Attorney Single Page Sidebar Style', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select Sidebar Style', 'attorneypress' ),
			'options'  => array(
				'attorney-single-sidebar-style-one' => esc_html__( 'Colored Sidebar', 'attorneypress' ),
				'attorney-single-sidebar-style-two' => esc_html__( 'White Sidebar', 'attorneypress' ),
			),
			'default'  => 'attorney-single-sidebar-style-one',
			'required' => array(
				array(
					'attorney-single-page-layout',
					'!=',
					'no-sidebar-layout',
				),
			),
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Practice Area Single Page Layout', 'attorneypress' ),
	'desc'       => '',
	'subsection' => true,
	'submenu'    => true,
	'icon'       => 'fa fa-graduation-cap',
	'fields'     => array(
		array(
			'id'       => 'practice-area-single-page-layout',
			'type'     => 'image_select',
			'title'    => esc_html__( 'Practice Area Single Page Layout', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select Practice Area single page layout', 'attorneypress' ),
			'options'  => array(
				'practice-area-single-left-sidebar' => array(
					'alt'   => esc_html__( 'Layout Left Sidebar', 'attorneypress' ),
					'title' => esc_html__( 'Layout Left Sidebar', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Practice-Area-Single-01.jpg' ),
				),
				'practice-area-single-without-sidebar' => array(
					'alt'   => esc_html__( 'Layout No Sidebar', 'attorneypress' ),
					'title' => esc_html__( 'Layout No Sidebar', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Practice-Area-Single-02.jpg' ),
				),
				'practice-area-single-right-sidebar' => array(
					'alt'   => esc_html__( 'Layout Right Sidebar', 'attorneypress' ),
					'title' => esc_html__( 'Layout Right Sidebar', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Practice-Area-Single-03.jpg' ),
				),
			),
			'default'  => 'practice-area-single-left-sidebar',
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title' => esc_html__( 'Blog', 'attorneypress' ),
	'icon'  => 'fa fa-microphone',
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Blog Layout', 'attorneypress' ),
	'icon'       => 'fa fa-th-large',
	'subsection' => true,
	'fields'     => array(
		array(
			'id'       => 'blog-style',
			'type'     => 'image_select',
			'title'    => esc_html__( 'Blog Style', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select blog style', 'attorneypress' ),
			'options'  => array(
				'one' => array(
					'alt'   => esc_html__( 'Boxed Style', 'attorneypress' ),
					'title' => esc_html__( 'Boxed Style', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Blog-Style-01.jpg' ),
				),
				'two' => array(
					'alt'   => esc_html__( 'Full Width Style', 'attorneypress' ),
					'title' => esc_html__( 'Full Width Style', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Blog-Style-02.jpg' ),
				),
				'three' => array(
					'alt'   => esc_html__( 'Masonry Style', 'attorneypress' ),
					'title' => esc_html__( 'Masonry Style', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Blog-Style-03.jpg' ),
				),
			),
			'default'  => 'two',
		),
		array(
			'id'       => 'blog-layout',
			'type'     => 'image_select',
			'title'    => esc_html__( 'Blog Layout', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select blog layout', 'attorneypress' ),
			'options'  => array(
				'leftsidebar' => array(
					'alt'   => esc_html__( 'Left Sidebar', 'attorneypress' ),
					'title' => esc_html__( 'Left Sidebar', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Blog-Layout-Left-Sidebar.jpg' ),
				),
				'nosidebar' => array(
					'alt'   => esc_html__( 'No Sidebar', 'attorneypress' ),
					'title' => esc_html__( 'No Sidebar', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Blog-Layout-No-Sidebar.jpg' ),
				),
				'rightsidebar' => array(
					'alt'   => esc_html__( 'Right Sidebar', 'attorneypress' ),
					'title' => esc_html__( 'Right Sidebar', 'attorneypress' ),
					'img'   => get_parent_theme_file_uri( '/inc/redux-framework/css/img/Blog-Layout-Right-Sidebar.jpg' ),
				),
			),
			'default'  => 'rightsidebar',
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Blog Options', 'attorneypress' ),
	'subsection' => true,
	'icon'       => 'fa fa-filter',
	'fields'     => array(
		array(
			'id'       => 'search_page_banner_image',
			'type'     => 'media',
			'url'      => false,
			'title'    => esc_html__( 'Search Page Banner Image', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select search page banner image', 'attorneypress' ),
		),
		array(
			'id'       => 'search_page_banner_title',
			'type'     => 'text',
			'title'    => esc_html__( 'Search Page Title', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter search page banner title', 'attorneypress' ),
			'default'  => 'Search',
		),
		array(
			'id'    => 'seo-blog-title',
			'type'  => 'text',
			'title' => esc_html__( 'Blog Page Meta(SEO) Title', 'attorneypress' ),
		),
		array(
			'id'    => 'seo-blog-description',
			'type'  => 'textarea',
			'title' => esc_html__( 'Blog Page Meta(SEO) Description', 'attorneypress' ),
		),
		array(
			'id'       => 'blog_comment_display',
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable Comments', 'attorneypress' ),
			'subtitle' => esc_html__( 'Do you want to enable comments on blog single page?', 'attorneypress' ),
			'default'  => true,
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'      => esc_html__( 'Blog Typography', 'attorneypress' ),
	'subsection' => true,
	'icon'       => 'fa fa-text-height',
	'fields'     => array(
		array(
			'id'             => 'general_blog_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'General', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font of your blog.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'letter-spacing' => true,
			'font-style'     => true,
			'all_styles'     => true,
			'output'         => array( '.entry-main' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Montserrat',
				'font-weight' => '300',
				'font-size'   => '15px',
				'color'       => '#393939',
				'line-height' => '26px',
			),
		),
		array(
			'id'             => 'h1_blog_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'H1', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font for all H1 tags of your website.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'font-weight'    => true,
			'font-style'     => true,
			'line-height'    => true,
			'letter-spacing' => true,
			'font-family'    => true,
			'color'          => true,
			'all_styles'     => false,
			'output'         => array( '.entry-main h1' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Libre Baskerville',
				'font-weight' => '400',
				'font-size'   => '30px',
				'color'       => '#393939',
				'line-height' => '40px',
			),
		),
		array(
			'id'             => 'h2_blog_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'H2', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font for all H2 tags of your website.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'font-weight'    => true,
			'font-style'     => true,
			'line-height'    => true,
			'letter-spacing' => true,
			'font-family'    => true,
			'color'          => true,
			'all_styles'     => false,
			'output'         => array( '.entry-main h2' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Libre Baskerville',
				'font-weight' => '400',
				'font-size'   => '26px',
				'color'       => '#393939',
				'line-height' => '35px',
			),
		),
		array(
			'id'             => 'h3_blog_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'H3', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font for all H3 tags of your website.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'font-weight'    => true,
			'font-style'     => true,
			'line-height'    => true,
			'letter-spacing' => true,
			'font-family'    => true,
			'color'          => true,
			'all_styles'     => false,
			'output'         => array( '.entry-main h3' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Libre Baskerville',
				'font-weight' => '400',
				'font-size'   => '23px',
				'color'       => '#393939',
				'line-height' => '35px',
			),
		),
		array(
			'id'             => 'h4_blog_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'H4', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font for all H4 tags of your website.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'font-weight'    => true,
			'font-style'     => true,
			'line-height'    => true,
			'letter-spacing' => true,
			'font-family'    => true,
			'color'          => true,
			'all_styles'     => false,
			'output'         => array( '.entry-main h4' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Libre Baskerville',
				'font-weight' => '400',
				'font-size'   => '22px',
				'color'       => '#393939',
				'line-height' => '35px',
			),
		),
		array(
			'id'             => 'h5_blog_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'H5', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font for all H5 tags of your website.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'font-weight'    => true,
			'font-style'     => true,
			'line-height'    => true,
			'letter-spacing' => true,
			'font-family'    => true,
			'color'          => true,
			'all_styles'     => false,
			'output'         => array( '.entry-main h5' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Bitter',
				'font-weight' => '400',
				'font-size'   => '20px',
				'color'       => '#393939',
				'line-height' => '30px',
			),
		),
		array(
			'id'             => 'h6_blog_typography',
			'type'           => 'typography',
			'title'          => esc_html__( 'H6', 'attorneypress' ),
			'subtitle'       => esc_html__( 'This will be the default font for all H6 tags of your website.', 'attorneypress' ),
			'google'         => true,
			'font-backup'    => true,
			'text-align'     => false,
			'font-weight'    => true,
			'font-style'     => true,
			'line-height'    => true,
			'letter-spacing' => true,
			'font-family'    => true,
			'color'          => true,
			'all_styles'     => false,
			'output'         => array( '.entry-main h6' ),
			'units'          => 'px',
			'default'        => array(
				'google'      => true,
				'font-family' => 'Bitter',
				'font-weight' => '400',
				'font-size'   => '14px',
				'color'       => '#393939',
				'line-height' => '22px',
			),
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'   => esc_html__( '404 Page', 'attorneypress' ),
	'submenu' => true,
	'icon'    => 'fa fa-exclamation-triangle',
	'fields'  => array(
		array(
			'id'       => 'page_not_found_banner_image',
			'type'     => 'media',
			'url'      => false,
			'title'    => esc_html__( '404 Banner Image', 'attorneypress' ),
			'subtitle' => esc_html__( 'Select 404 banner image', 'attorneypress' ),
		),
		array(
			'id'       => 'page_not_found_banner_title',
			'type'     => 'text',
			'title'    => esc_html__( '404 Banner Page Title', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter 404 banner page title', 'attorneypress' ),
			'default'  => esc_html__( 'Sorry! 404 Error', 'attorneypress' ),
		),
		array(
			'id'       => 'page_not_found_body',
			'type'     => 'editor',
			'title'    => esc_html__( '404 Page Body', 'attorneypress' ),
			'subtitle' => esc_html__( 'Enter data to show on 404 page body', 'attorneypress' ),
			'default'  => wp_kses_post( '<h1>Page Not Found</h1><p>We are sorry, the page you are looking for cannot be found.</p>' ),
			'args'     => array(
				'teeny' => false,
			),
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'            => esc_html__( 'SEO Options', 'attorneypress' ),
	'id'               => 'seo',
	'desc'             => esc_html__( 'These are really basic fields!', 'attorneypress' ),
	'customizer_width' => '400px',
	'icon'             => 'fa fa-bullseye',
) );

Redux::setSection( $opt_name, array(
	'title'            => esc_html__( 'SEO Fields', 'attorneypress' ),
	'id'               => 'seo-fields',
	'icon'             => 'fa fa-square-o',
	'subsection'       => true,
	'customizer_width' => '450px',
	'fields'           => array(
		array(
			'id'       => 'enable_attorneypress_theme_seo',
			'type'     => 'switch',
			'title'    => esc_html__( 'Display WordPress Theme SEO Plugin', 'attorneypress' ),
			'desc'     => esc_html__( 'If its disabled then the Seo Title and Description will not display.', 'attorneypress' ),
			'default'  => true,
			'subtitle' => esc_html__( 'Turn it OFF if you want to use external SEO plugin', 'attorneypress' ),
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'            => esc_html__( 'Google', 'attorneypress' ),
	'id'               => 'seo-google',
	'subsection'       => true,
	'icon'             => 'fa fa-google',
	'customizer_width' => '500px',
	'fields'           => array(
		array(
			'id'       => 'seo-google-site-verification',
			'type'     => 'text',
			'title'    => esc_html__( 'Google Site Verification', 'attorneypress' ),
			'subtitle' => esc_html__( 'Paste your Google Site Verification token here', 'attorneypress' ),
		),
		array(
			'id'   => 'seo-google-site-verification-info',
			'type' => 'info',
			'desc' => wp_kses_post( '<h5>For google site verification Paste full string code see the below screen shot.</h5><img src="' . get_parent_theme_file_uri( '/inc/redux-framework/css/img/google-site-verification.jpg' ) . '" alt="google-site-verification">' ),
		),
		array(
			'id'       => 'seo-google-remarketing',
			'type'     => 'textarea',
			'title'    => esc_html__( 'Google | Remarketing', 'attorneypress' ),
			'subtitle' => esc_html__( 'Paste your Google Remarketing code here', 'attorneypress' ),
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'            => esc_html__( 'Advanced', 'attorneypress' ),
	'id'               => 'seo-advanced',
	'icon'             => 'fa fa-floppy-o',
	'subsection'       => true,
	'customizer_width' => '500px',
	'fields'           => array(
		array(
			'id'       => 'seo-schema-type',
			'type'     => 'switch',
			'default'  => true,
			'title'    => esc_html__( 'Schema Type', 'attorneypress' ),
			'subtitle' => esc_html__( 'Add Schema Type to &lt;html&gt; tag', 'attorneypress' ),
		),
	),
) );

Redux::setSection( $opt_name, array(
	'title'            => esc_html__( 'XML Sitemaps', 'attorneypress' ),
	'id'               => 'seo-sitemaps',
	'icon'             => 'fa fa-sitemap',
	'subsection'       => true,
	'customizer_width' => '500px',
	'desc'             => esc_html__( 'You can find your XML Sitemap here : ', 'attorneypress' ) . '<a href="' . get_home_url() . '/sitemap.xml" target="_blank">XML Sitemaps</a>',
	'fields'           => array(
		array(
			'id'       => 'seo-posts-exclude',
			'type'     => 'textarea',
			'title'    => esc_html__( 'Posts to exclude', 'attorneypress' ),
			'subtitle' => esc_html__( 'You can exclude posts from the sitemap by entering a comma separated string with the Post ID The format will become something like 1,95,209', 'attorneypress' ),
		),
	),
) );

Redux::setSection(
	$opt_name, array(
		'title'   => esc_html__( 'Custom CSS', 'attorneypress' ),
		'submenu' => false,
		'icon'    => 'el el-css',
		'fields'  => array(

			// Radiant Custom CSS.
			array(
                'id'       => 'attorneypress_custom_css',
                'type'     => 'ace_editor',
                'title'    => esc_html__('Attorneypress Custom CSS', 'attorneypress'),
                'subtitle' => esc_html__('Paste your custom CSS here.', 'attorneypress'),
                'mode'     => 'css',
                'theme'    => 'chrome',
                'default'  => ".my-custom-item{font-size:20px}",
            ),

		),
	)
);
