<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package attorneypress
 */

if ( ! function_exists( 'attorneypress_schema' ) ) :
	/**
	 * Displays schema in html tag if 'Schema Type' in Theme Options is set to true
	 */
	function attorneypress_schema() {
		if ( true == attorneypress_global_var( 'seo-schema-type','',false ) ) {
			echo 'itemscope="itemscope" itemtype="' . esc_url( __( 'http://schema.org/WebPage', 'attorneypress' ) ) . '"';
		}
	}
endif;

if ( ! function_exists( 'attorneypress_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function attorneypress_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
		}

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date() )
		);

		echo '<span class="posted-on"><i class="fa fa-calendar-o"></i>';

		$posted_on = sprintf(
			// translators: ff.
			esc_html( '%s', 'post date' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

		$byline = sprintf(
			// translators: Author Name and Link.
			esc_html( '%s', 'post author' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

		echo wp_kses_post( '' . $posted_on . '</span>' );
		echo wp_kses_post( '<span class="author"><i class="fa fa-user-circle-o"></i>' . $byline . '</span>' ); // WPCS: XSS OK.

		if ( attorneypress_global_var( 'blog_comment_display','',false ) ) {
			comments_number( '<span class="comment-count"><i class="fa fa-comments-o"></i>No Comments</span>', '<span class="comment-count"><i class="fa fa-comments-o"></i>1 Comment</span>', '<span class="comment-count"><i class="fa fa-comments-o"></i>% Comments</span>' ); // COMMENT COUNT.
		}

		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'attorneypress' ) );
			if ( $categories_list && attorneypress_categorized_blog() ) {
				printf(
					wp_kses_post( '<span class="cat-links"><i class="fa fa-folder-open-o"></i>' ) .
					/* translators: used between list items, there is a space after the comma */
					esc_html__( 'Categories: %1$s', 'attorneypress' ) .
					wp_kses_post( '</span>' ),
					wp_kses_post( $categories_list )
				);
			}

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html__( ', ', 'attorneypress' ) );
			if ( $tags_list ) {
				printf(
					wp_kses_post( '<span class="tags-links"><i class="fa fa-tags"></i>' ) .
					/* translators: used between list items, there is a space after the comma */
					esc_html__( 'Tags: %1$s', 'attorneypress' ) .
					wp_kses_post( '</span>' ),
					wp_kses_post( $tags_list )
				); // WPCS: XSS OK.
			}
		}
	}
endif;

if ( ! function_exists( 'attorneypress_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function attorneypress_entry_footer() {

	?>

		<span class="cat-links">
			<?php
			$category_detail = get_the_category( get_the_id() );
			foreach ( $category_detail as $cd ) {
				echo esc_html( $cd->cat_name );
			}
?>
		</span>

		<?php
		if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo wp_kses_post( '<span class="comments-link">' );
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						esc_html_e( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'attorneypress' ), array(
							'span' => array(
								'class' => array(),
							),
						)
					), get_the_title()
				)
			);
			echo wp_kses_post( '</span>' );
		}

	}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function attorneypress_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'attorneypress_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories(
			array(
				'fields'     => 'ids',
				'hide_empty' => 1,
				// We only need to know if there is more than one category.
				'number'     => 2,
			)
		);

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'attorneypress_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so attorneypress_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so attorneypress_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in attorneypress_categorized_blog.
 */
function attorneypress_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'attorneypress_categories' );
}
add_action( 'edit_category', 'attorneypress_category_transient_flusher' );
add_action( 'save_post',     'attorneypress_category_transient_flusher' );

if ( ! function_exists( 'attorneypress_global_var' ) ) {
	/**
	 * [attorneypress_global_var description]
	 *
	 * @param  [type] $attorneypress_opt_one   description.
	 * @param  [type] $attorneypress_opt_two   description.
	 * @param  [type] $attorneypress_opt_check description.
	 * @return [type]                          description
	 */
	function attorneypress_global_var(
		$attorneypress_opt_one,
		$attorneypress_opt_two,
		$attorneypress_opt_check
	) {
		global $attorneypress_theme_option;
		if ( $attorneypress_opt_check ) {
			if ( isset( $attorneypress_theme_option[ $attorneypress_opt_one ][ $attorneypress_opt_two ] ) ) {
				return $attorneypress_theme_option[ $attorneypress_opt_one ][ $attorneypress_opt_two ];
			}
		} else {
			if ( isset( $attorneypress_theme_option[ $attorneypress_opt_one ] ) ) {
				return $attorneypress_theme_option[ $attorneypress_opt_one ];
			}
		}
	}
}
